# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_sagemaker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_sagemaker.proto\x12\x19oak9.tython.aws.sagemaker\x1a\x13shared/shared.proto\"\x8e\x01\n\x17\x43odeRepositoryGitConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nsecret_arn\x18\x02 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x03 \x01(\t\x12\x16\n\x0erepository_url\x18\x04 \x01(\t\"\xaf\x01\n\x0e\x43odeRepository\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x63ode_repository_name\x18\x02 \x01(\t\x12\x46\n\ngit_config\x18\x03 \x01(\x0b\x32\x32.oak9.tython.aws.sagemaker.CodeRepositoryGitConfig\"\xae\x04\n\tSageMaker\x12\x42\n\x0f\x63ode_repository\x18\x01 \x03(\x0b\x32).oak9.tython.aws.sagemaker.CodeRepository\x12\x35\n\x08\x65ndpoint\x18\x02 \x03(\x0b\x32#.oak9.tython.aws.sagemaker.Endpoint\x12\x42\n\x0f\x65ndpoint_config\x18\x03 \x03(\x0b\x32).oak9.tython.aws.sagemaker.EndpointConfig\x12/\n\x05model\x18\x04 \x03(\x0b\x32 .oak9.tython.aws.sagemaker.Model\x12J\n\x13monitoring_schedule\x18\x05 \x03(\x0b\x32-.oak9.tython.aws.sagemaker.MonitoringSchedule\x12\x46\n\x11notebook_instance\x18\x06 \x03(\x0b\x32+.oak9.tython.aws.sagemaker.NotebookInstance\x12\x66\n\"notebook_instance_lifecycle_config\x18\x07 \x03(\x0b\x32:.oak9.tython.aws.sagemaker.NotebookInstanceLifecycleConfig\x12\x35\n\x08workteam\x18\x08 \x03(\x0b\x32#.oak9.tython.aws.sagemaker.Workteam\"q\n\x17\x45ndpointVariantProperty\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15variant_property_type\x18\x02 \x01(\t\"\xea\x02\n\x08\x45ndpoint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12%\n\x1dretain_all_variant_properties\x18\x02 \x01(\x08\x12\x15\n\rendpoint_name\x18\x03 \x01(\t\x12_\n#exclude_retained_variant_properties\x18\x04 \x03(\x0b\x32\x32.oak9.tython.aws.sagemaker.EndpointVariantProperty\x12\x1c\n\x14\x65ndpoint_config_name\x18\x05 \x01(\t\x12;\n\x04tags\x18\x06 \x03(\x0b\x32-.oak9.tython.aws.sagemaker.Endpoint.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"l\n\x1b\x45ndpointConfigCaptureOption\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63\x61pture_mode\x18\x02 \x01(\t\"\x98\x01\n&EndpointConfigCaptureContentTypeHeader\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12json_content_types\x18\x02 \x03(\t\x12\x19\n\x11\x63sv_content_types\x18\x03 \x03(\t\"\x80\x03\n\x1f\x45ndpointConfigDataCaptureConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12O\n\x0f\x63\x61pture_options\x18\x02 \x03(\x0b\x32\x36.oak9.tython.aws.sagemaker.EndpointConfigCaptureOption\x12\x12\n\nkms_key_id\x18\x03 \x01(\t\x12\x1a\n\x12\x64\x65stination_s3_uri\x18\x04 \x01(\t\x12#\n\x1binitial_sampling_percentage\x18\x05 \x01(\x05\x12\x66\n\x1b\x63\x61pture_content_type_header\x18\x06 \x01(\x0b\x32\x41.oak9.tython.aws.sagemaker.EndpointConfigCaptureContentTypeHeader\x12\x16\n\x0e\x65nable_capture\x18\x07 \x01(\x08\"\xf5\x01\n\x1f\x45ndpointConfigProductionVariant\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nmodel_name\x18\x02 \x01(\t\x12\x14\n\x0cvariant_name\x18\x03 \x01(\t\x12\x1e\n\x16initial_instance_count\x18\x04 \x01(\x05\x12\x15\n\rinstance_type\x18\x05 \x01(\t\x12\x18\n\x10\x61\x63\x63\x65lerator_type\x18\x06 \x01(\t\x12\x1e\n\x16initial_variant_weight\x18\x07 \x01(\x01\"\x9d\x03\n\x0e\x45ndpointConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12W\n\x13\x64\x61ta_capture_config\x18\x02 \x01(\x0b\x32:.oak9.tython.aws.sagemaker.EndpointConfigDataCaptureConfig\x12W\n\x13production_variants\x18\x03 \x03(\x0b\x32:.oak9.tython.aws.sagemaker.EndpointConfigProductionVariant\x12\x12\n\nkms_key_id\x18\x04 \x01(\t\x12\x1c\n\x14\x65ndpoint_config_name\x18\x05 \x01(\t\x12\x41\n\x04tags\x18\x06 \x03(\x0b\x32\x33.oak9.tython.aws.sagemaker.EndpointConfig.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcf\x02\n\x18ModelContainerDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12\x63ontainer_hostname\x18\x02 \x01(\t\x12\x1a\n\x12model_package_name\x18\x03 \x01(\t\x12\x0c\n\x04mode\x18\x04 \x01(\t\x12Y\n\x0b\x65nvironment\x18\x05 \x03(\x0b\x32\x44.oak9.tython.aws.sagemaker.ModelContainerDefinition.EnvironmentEntry\x12\x16\n\x0emodel_data_url\x18\x06 \x01(\t\x12\r\n\x05image\x18\x07 \x01(\t\x1a\x32\n\x10\x45nvironmentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"v\n\x0eModelVpcConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07subnets\x18\x02 \x03(\t\x12\x1a\n\x12security_group_ids\x18\x03 \x03(\t\"\xd1\x03\n\x05Model\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12\x65xecution_role_arn\x18\x02 \x01(\t\x12 \n\x18\x65nable_network_isolation\x18\x03 \x01(\x08\x12N\n\x11primary_container\x18\x04 \x01(\x0b\x32\x33.oak9.tython.aws.sagemaker.ModelContainerDefinition\x12\x12\n\nmodel_name\x18\x05 \x01(\t\x12=\n\nvpc_config\x18\x06 \x01(\x0b\x32).oak9.tython.aws.sagemaker.ModelVpcConfig\x12G\n\ncontainers\x18\x07 \x03(\x0b\x32\x33.oak9.tython.aws.sagemaker.ModelContainerDefinition\x12\x38\n\x04tags\x18\x08 \x03(\x0b\x32*.oak9.tython.aws.sagemaker.Model.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"p\n%MonitoringScheduleConstraintsResource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06s3_uri\x18\x02 \x01(\t\"o\n$MonitoringScheduleStatisticsResource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06s3_uri\x18\x02 \x01(\t\"\x99\x02\n MonitoringScheduleBaselineConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12^\n\x14\x63onstraints_resource\x18\x02 \x01(\x0b\x32@.oak9.tython.aws.sagemaker.MonitoringScheduleConstraintsResource\x12\\\n\x13statistics_resource\x18\x03 \x01(\x0b\x32?.oak9.tython.aws.sagemaker.MonitoringScheduleStatisticsResource\"X\n\x1dMonitoringScheduleEnvironment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8a\x02\n,MonitoringScheduleMonitoringAppSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x63ontainer_arguments\x18\x02 \x03(\t\x12\x1c\n\x14\x63ontainer_entrypoint\x18\x03 \x03(\t\x12\x11\n\timage_uri\x18\x04 \x01(\t\x12+\n#post_analytics_processor_source_uri\x18\x05 \x01(\t\x12&\n\x1erecord_preprocessor_source_uri\x18\x06 \x01(\t\"\xbf\x01\n\x1fMonitoringScheduleEndpointInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rendpoint_name\x18\x02 \x01(\t\x12\x12\n\nlocal_path\x18\x03 \x01(\t\x12!\n\x19s3_data_distribution_type\x18\x04 \x01(\t\x12\x15\n\rs3_input_mode\x18\x05 \x01(\t\"\xb0\x01\n!MonitoringScheduleMonitoringInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x0e\x65ndpoint_input\x18\x02 \x01(\x0b\x32:.oak9.tython.aws.sagemaker.MonitoringScheduleEndpointInput\"\xb6\x01\n\"MonitoringScheduleMonitoringInputs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12W\n\x11monitoring_inputs\x18\x02 \x03(\x0b\x32<.oak9.tython.aws.sagemaker.MonitoringScheduleMonitoringInput\"\x91\x01\n\x1aMonitoringScheduleS3Output\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nlocal_path\x18\x02 \x01(\t\x12\x16\n\x0es3_upload_mode\x18\x03 \x01(\t\x12\x0e\n\x06s3_uri\x18\x04 \x01(\t\"\xa7\x01\n\"MonitoringScheduleMonitoringOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12H\n\ts3_output\x18\x02 \x01(\x0b\x32\x35.oak9.tython.aws.sagemaker.MonitoringScheduleS3Output\"\xd2\x01\n(MonitoringScheduleMonitoringOutputConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nkms_key_id\x18\x02 \x01(\t\x12Y\n\x12monitoring_outputs\x18\x03 \x03(\x0b\x32=.oak9.tython.aws.sagemaker.MonitoringScheduleMonitoringOutput\"\xbf\x01\n\x1fMonitoringScheduleClusterConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0einstance_count\x18\x02 \x01(\x05\x12\x15\n\rinstance_type\x18\x03 \x01(\t\x12\x19\n\x11volume_kms_key_id\x18\x04 \x01(\t\x12\x19\n\x11volume_size_in_gb\x18\x05 \x01(\x05\"\xb4\x01\n%MonitoringScheduleMonitoringResources\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x0e\x63luster_config\x18\x02 \x01(\x0b\x32:.oak9.tython.aws.sagemaker.MonitoringScheduleClusterConfig\"\x83\x01\n\x1bMonitoringScheduleVpcConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12security_group_ids\x18\x02 \x03(\t\x12\x0f\n\x07subnets\x18\x03 \x03(\t\"\xfb\x01\n\x1fMonitoringScheduleNetworkConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x31\n)enable_inter_container_traffic_encryption\x18\x02 \x01(\x08\x12 \n\x18\x65nable_network_isolation\x18\x03 \x01(\x08\x12J\n\nvpc_config\x18\x04 \x01(\x0b\x32\x36.oak9.tython.aws.sagemaker.MonitoringScheduleVpcConfig\"~\n#MonitoringScheduleStoppingCondition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16max_runtime_in_seconds\x18\x02 \x01(\x05\"\xdb\x06\n)MonitoringScheduleMonitoringJobDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12T\n\x0f\x62\x61seline_config\x18\x02 \x01(\x0b\x32;.oak9.tython.aws.sagemaker.MonitoringScheduleBaselineConfig\x12M\n\x0b\x65nvironment\x18\x03 \x01(\x0b\x32\x38.oak9.tython.aws.sagemaker.MonitoringScheduleEnvironment\x12m\n\x1cmonitoring_app_specification\x18\x04 \x01(\x0b\x32G.oak9.tython.aws.sagemaker.MonitoringScheduleMonitoringAppSpecification\x12X\n\x11monitoring_inputs\x18\x05 \x01(\x0b\x32=.oak9.tython.aws.sagemaker.MonitoringScheduleMonitoringInputs\x12\x65\n\x18monitoring_output_config\x18\x06 \x01(\x0b\x32\x43.oak9.tython.aws.sagemaker.MonitoringScheduleMonitoringOutputConfig\x12^\n\x14monitoring_resources\x18\x07 \x01(\x0b\x32@.oak9.tython.aws.sagemaker.MonitoringScheduleMonitoringResources\x12R\n\x0enetwork_config\x18\x08 \x01(\x0b\x32:.oak9.tython.aws.sagemaker.MonitoringScheduleNetworkConfig\x12\x10\n\x08role_arn\x18\t \x01(\t\x12Z\n\x12stopping_condition\x18\n \x01(\x0b\x32>.oak9.tython.aws.sagemaker.MonitoringScheduleStoppingCondition\"x\n MonitoringScheduleScheduleConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13schedule_expression\x18\x02 \x01(\t\"\xa4\x02\n*MonitoringScheduleMonitoringScheduleConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12g\n\x19monitoring_job_definition\x18\x02 \x01(\x0b\x32\x44.oak9.tython.aws.sagemaker.MonitoringScheduleMonitoringJobDefinition\x12T\n\x0fschedule_config\x18\x03 \x01(\x0b\x32;.oak9.tython.aws.sagemaker.MonitoringScheduleScheduleConfig\"\xc4\x02\n,MonitoringScheduleMonitoringExecutionSummary\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rcreation_time\x18\x02 \x01(\t\x12\x15\n\rendpoint_name\x18\x03 \x01(\t\x12\x16\n\x0e\x66\x61ilure_reason\x18\x04 \x01(\t\x12\x1a\n\x12last_modified_time\x18\x05 \x01(\t\x12#\n\x1bmonitoring_execution_status\x18\x06 \x01(\t\x12 \n\x18monitoring_schedule_name\x18\x07 \x01(\t\x12\x1a\n\x12processing_job_arn\x18\x08 \x01(\t\x12\x16\n\x0escheduled_time\x18\t \x01(\t\"\xe9\x04\n\x12MonitoringSchedule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17monitoring_schedule_arn\x18\x02 \x01(\t\x12 \n\x18monitoring_schedule_name\x18\x03 \x01(\t\x12i\n\x1amonitoring_schedule_config\x18\x04 \x01(\x0b\x32\x45.oak9.tython.aws.sagemaker.MonitoringScheduleMonitoringScheduleConfig\x12\x45\n\x04tags\x18\x05 \x03(\x0b\x32\x37.oak9.tython.aws.sagemaker.MonitoringSchedule.TagsEntry\x12\x15\n\rcreation_time\x18\x06 \x01(\t\x12\x15\n\rendpoint_name\x18\x07 \x01(\t\x12\x16\n\x0e\x66\x61ilure_reason\x18\x08 \x01(\t\x12\x1a\n\x12last_modified_time\x18\t \x01(\t\x12r\n!last_monitoring_execution_summary\x18\n \x01(\x0b\x32G.oak9.tython.aws.sagemaker.MonitoringScheduleMonitoringExecutionSummary\x12\"\n\x1amonitoring_schedule_status\x18\x0b \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x04\n\x10NotebookInstance\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nkms_key_id\x18\x02 \x01(\t\x12\x19\n\x11volume_size_in_gb\x18\x03 \x01(\x05\x12$\n\x1c\x61\x64\x64itional_code_repositories\x18\x04 \x03(\t\x12\x1f\n\x17\x64\x65\x66\x61ult_code_repository\x18\x05 \x01(\t\x12\x1e\n\x16\x64irect_internet_access\x18\x06 \x01(\t\x12\x19\n\x11\x61\x63\x63\x65lerator_types\x18\x07 \x03(\t\x12\x11\n\tsubnet_id\x18\x08 \x01(\t\x12\x1a\n\x12security_group_ids\x18\t \x03(\t\x12\x10\n\x08role_arn\x18\n \x01(\t\x12\x13\n\x0broot_access\x18\x0b \x01(\t\x12\x1e\n\x16notebook_instance_name\x18\x0c \x01(\t\x12\x15\n\rinstance_type\x18\r \x01(\t\x12\x1d\n\x15lifecycle_config_name\x18\x0e \x01(\t\x12\x43\n\x04tags\x18\x0f \x03(\x0b\x32\x35.oak9.tython.aws.sagemaker.NotebookInstance.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x01\n<NotebookInstanceLifecycleConfigNotebookInstanceLifecycleHook\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\"\xe2\x02\n\x1fNotebookInstanceLifecycleConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12i\n\x08on_start\x18\x02 \x03(\x0b\x32W.oak9.tython.aws.sagemaker.NotebookInstanceLifecycleConfigNotebookInstanceLifecycleHook\x12/\n\'notebook_instance_lifecycle_config_name\x18\x03 \x01(\t\x12j\n\ton_create\x18\x04 \x03(\x0b\x32W.oak9.tython.aws.sagemaker.NotebookInstanceLifecycleConfigNotebookInstanceLifecycleHook\"|\n!WorkteamNotificationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16notification_topic_arn\x18\x02 \x01(\t\"\xac\x01\n\x1fWorkteamCognitoMemberDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x63ognito_user_pool\x18\x02 \x01(\t\x12\x19\n\x11\x63ognito_client_id\x18\x03 \x01(\t\x12\x1a\n\x12\x63ognito_user_group\x18\x04 \x01(\t\"\xb2\x01\n\x18WorkteamMemberDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12]\n\x19\x63ognito_member_definition\x18\x02 \x01(\x0b\x32:.oak9.tython.aws.sagemaker.WorkteamCognitoMemberDefinition\"\x8c\x03\n\x08Workteam\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12`\n\x1anotification_configuration\x18\x03 \x01(\x0b\x32<.oak9.tython.aws.sagemaker.WorkteamNotificationConfiguration\x12\x15\n\rworkteam_name\x18\x04 \x01(\t\x12O\n\x12member_definitions\x18\x05 \x03(\x0b\x32\x33.oak9.tython.aws.sagemaker.WorkteamMemberDefinition\x12;\n\x04tags\x18\x06 \x03(\x0b\x32-.oak9.tython.aws.sagemaker.Workteam.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_sagemaker_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENDPOINT_TAGSENTRY._options = None
  _ENDPOINT_TAGSENTRY._serialized_options = b'8\001'
  _ENDPOINTCONFIG_TAGSENTRY._options = None
  _ENDPOINTCONFIG_TAGSENTRY._serialized_options = b'8\001'
  _MODELCONTAINERDEFINITION_ENVIRONMENTENTRY._options = None
  _MODELCONTAINERDEFINITION_ENVIRONMENTENTRY._serialized_options = b'8\001'
  _MODEL_TAGSENTRY._options = None
  _MODEL_TAGSENTRY._serialized_options = b'8\001'
  _MONITORINGSCHEDULE_TAGSENTRY._options = None
  _MONITORINGSCHEDULE_TAGSENTRY._serialized_options = b'8\001'
  _NOTEBOOKINSTANCE_TAGSENTRY._options = None
  _NOTEBOOKINSTANCE_TAGSENTRY._serialized_options = b'8\001'
  _WORKTEAM_TAGSENTRY._options = None
  _WORKTEAM_TAGSENTRY._serialized_options = b'8\001'
  _CODEREPOSITORYGITCONFIG._serialized_start=76
  _CODEREPOSITORYGITCONFIG._serialized_end=218
  _CODEREPOSITORY._serialized_start=221
  _CODEREPOSITORY._serialized_end=396
  _SAGEMAKER._serialized_start=399
  _SAGEMAKER._serialized_end=957
  _ENDPOINTVARIANTPROPERTY._serialized_start=959
  _ENDPOINTVARIANTPROPERTY._serialized_end=1072
  _ENDPOINT._serialized_start=1075
  _ENDPOINT._serialized_end=1437
  _ENDPOINT_TAGSENTRY._serialized_start=1394
  _ENDPOINT_TAGSENTRY._serialized_end=1437
  _ENDPOINTCONFIGCAPTUREOPTION._serialized_start=1439
  _ENDPOINTCONFIGCAPTUREOPTION._serialized_end=1547
  _ENDPOINTCONFIGCAPTURECONTENTTYPEHEADER._serialized_start=1550
  _ENDPOINTCONFIGCAPTURECONTENTTYPEHEADER._serialized_end=1702
  _ENDPOINTCONFIGDATACAPTURECONFIG._serialized_start=1705
  _ENDPOINTCONFIGDATACAPTURECONFIG._serialized_end=2089
  _ENDPOINTCONFIGPRODUCTIONVARIANT._serialized_start=2092
  _ENDPOINTCONFIGPRODUCTIONVARIANT._serialized_end=2337
  _ENDPOINTCONFIG._serialized_start=2340
  _ENDPOINTCONFIG._serialized_end=2753
  _ENDPOINTCONFIG_TAGSENTRY._serialized_start=1394
  _ENDPOINTCONFIG_TAGSENTRY._serialized_end=1437
  _MODELCONTAINERDEFINITION._serialized_start=2756
  _MODELCONTAINERDEFINITION._serialized_end=3091
  _MODELCONTAINERDEFINITION_ENVIRONMENTENTRY._serialized_start=3041
  _MODELCONTAINERDEFINITION_ENVIRONMENTENTRY._serialized_end=3091
  _MODELVPCCONFIG._serialized_start=3093
  _MODELVPCCONFIG._serialized_end=3211
  _MODEL._serialized_start=3214
  _MODEL._serialized_end=3679
  _MODEL_TAGSENTRY._serialized_start=1394
  _MODEL_TAGSENTRY._serialized_end=1437
  _MONITORINGSCHEDULECONSTRAINTSRESOURCE._serialized_start=3681
  _MONITORINGSCHEDULECONSTRAINTSRESOURCE._serialized_end=3793
  _MONITORINGSCHEDULESTATISTICSRESOURCE._serialized_start=3795
  _MONITORINGSCHEDULESTATISTICSRESOURCE._serialized_end=3906
  _MONITORINGSCHEDULEBASELINECONFIG._serialized_start=3909
  _MONITORINGSCHEDULEBASELINECONFIG._serialized_end=4190
  _MONITORINGSCHEDULEENVIRONMENT._serialized_start=4192
  _MONITORINGSCHEDULEENVIRONMENT._serialized_end=4280
  _MONITORINGSCHEDULEMONITORINGAPPSPECIFICATION._serialized_start=4283
  _MONITORINGSCHEDULEMONITORINGAPPSPECIFICATION._serialized_end=4549
  _MONITORINGSCHEDULEENDPOINTINPUT._serialized_start=4552
  _MONITORINGSCHEDULEENDPOINTINPUT._serialized_end=4743
  _MONITORINGSCHEDULEMONITORINGINPUT._serialized_start=4746
  _MONITORINGSCHEDULEMONITORINGINPUT._serialized_end=4922
  _MONITORINGSCHEDULEMONITORINGINPUTS._serialized_start=4925
  _MONITORINGSCHEDULEMONITORINGINPUTS._serialized_end=5107
  _MONITORINGSCHEDULES3OUTPUT._serialized_start=5110
  _MONITORINGSCHEDULES3OUTPUT._serialized_end=5255
  _MONITORINGSCHEDULEMONITORINGOUTPUT._serialized_start=5258
  _MONITORINGSCHEDULEMONITORINGOUTPUT._serialized_end=5425
  _MONITORINGSCHEDULEMONITORINGOUTPUTCONFIG._serialized_start=5428
  _MONITORINGSCHEDULEMONITORINGOUTPUTCONFIG._serialized_end=5638
  _MONITORINGSCHEDULECLUSTERCONFIG._serialized_start=5641
  _MONITORINGSCHEDULECLUSTERCONFIG._serialized_end=5832
  _MONITORINGSCHEDULEMONITORINGRESOURCES._serialized_start=5835
  _MONITORINGSCHEDULEMONITORINGRESOURCES._serialized_end=6015
  _MONITORINGSCHEDULEVPCCONFIG._serialized_start=6018
  _MONITORINGSCHEDULEVPCCONFIG._serialized_end=6149
  _MONITORINGSCHEDULENETWORKCONFIG._serialized_start=6152
  _MONITORINGSCHEDULENETWORKCONFIG._serialized_end=6403
  _MONITORINGSCHEDULESTOPPINGCONDITION._serialized_start=6405
  _MONITORINGSCHEDULESTOPPINGCONDITION._serialized_end=6531
  _MONITORINGSCHEDULEMONITORINGJOBDEFINITION._serialized_start=6534
  _MONITORINGSCHEDULEMONITORINGJOBDEFINITION._serialized_end=7393
  _MONITORINGSCHEDULESCHEDULECONFIG._serialized_start=7395
  _MONITORINGSCHEDULESCHEDULECONFIG._serialized_end=7515
  _MONITORINGSCHEDULEMONITORINGSCHEDULECONFIG._serialized_start=7518
  _MONITORINGSCHEDULEMONITORINGSCHEDULECONFIG._serialized_end=7810
  _MONITORINGSCHEDULEMONITORINGEXECUTIONSUMMARY._serialized_start=7813
  _MONITORINGSCHEDULEMONITORINGEXECUTIONSUMMARY._serialized_end=8137
  _MONITORINGSCHEDULE._serialized_start=8140
  _MONITORINGSCHEDULE._serialized_end=8757
  _MONITORINGSCHEDULE_TAGSENTRY._serialized_start=1394
  _MONITORINGSCHEDULE_TAGSENTRY._serialized_end=1437
  _NOTEBOOKINSTANCE._serialized_start=8760
  _NOTEBOOKINSTANCE._serialized_end=9298
  _NOTEBOOKINSTANCE_TAGSENTRY._serialized_start=1394
  _NOTEBOOKINSTANCE_TAGSENTRY._serialized_end=1437
  _NOTEBOOKINSTANCELIFECYCLECONFIGNOTEBOOKINSTANCELIFECYCLEHOOK._serialized_start=9301
  _NOTEBOOKINSTANCELIFECYCLECONFIGNOTEBOOKINSTANCELIFECYCLEHOOK._serialized_end=9437
  _NOTEBOOKINSTANCELIFECYCLECONFIG._serialized_start=9440
  _NOTEBOOKINSTANCELIFECYCLECONFIG._serialized_end=9794
  _WORKTEAMNOTIFICATIONCONFIGURATION._serialized_start=9796
  _WORKTEAMNOTIFICATIONCONFIGURATION._serialized_end=9920
  _WORKTEAMCOGNITOMEMBERDEFINITION._serialized_start=9923
  _WORKTEAMCOGNITOMEMBERDEFINITION._serialized_end=10095
  _WORKTEAMMEMBERDEFINITION._serialized_start=10098
  _WORKTEAMMEMBERDEFINITION._serialized_end=10276
  _WORKTEAM._serialized_start=10279
  _WORKTEAM._serialized_end=10675
  _WORKTEAM_TAGSENTRY._serialized_start=1394
  _WORKTEAM_TAGSENTRY._serialized_end=1437
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSkubernetes/kubernetes_io.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.proto\x12@oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\xbf\x01\n\x1e\x43ustomResourceColumnDefinition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x11\n\tjson_path\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08priority\x18\x05 \x01(\x05\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xcb\x01\n\x18\x43ustomResourceConversion\x12\x10\n\x08strategy\x18\x01 \x01(\t\x12\x64\n\x07webhook\x18\x02 \x01(\x0b\x32S.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.WebhookConversion\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa3\x03\n\x18\x43ustomResourceDefinition\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12l\n\x04spec\x18\x04 \x01(\x0b\x32^.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionSpec\x12p\n\x06status\x18\x05 \x01(\x0b\x32`.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xee\x01\n!CustomResourceDefinitionCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb0\x02\n\x1c\x43ustomResourceDefinitionList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12i\n\x05items\x18\x02 \x03(\x0b\x32Z.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceDefinition\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc4\x01\n\x1d\x43ustomResourceDefinitionNames\x12\x12\n\ncategories\x18\x01 \x03(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x11\n\tlist_kind\x18\x03 \x01(\t\x12\x0e\n\x06plural\x18\x04 \x01(\t\x12\x13\n\x0bshort_names\x18\x05 \x03(\t\x12\x10\n\x08singular\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xeb\x03\n\x1c\x43ustomResourceDefinitionSpec\x12n\n\nconversion\x18\x01 \x01(\x0b\x32Z.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceConversion\x12\r\n\x05group\x18\x02 \x01(\t\x12n\n\x05names\x18\x03 \x01(\x0b\x32_.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionNames\x12\x1f\n\x17preserve_unknown_fields\x18\x04 \x01(\x08\x12\r\n\x05scope\x18\x05 \x01(\t\x12s\n\x08versions\x18\x06 \x03(\x0b\x32\x61.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionVersion\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe4\x02\n\x1e\x43ustomResourceDefinitionStatus\x12w\n\x0e\x61\x63\x63\x65pted_names\x18\x01 \x01(\x0b\x32_.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionNames\x12w\n\nconditions\x18\x02 \x03(\x0b\x32\x63.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionCondition\x12\x17\n\x0fstored_versions\x18\x03 \x03(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa1\x04\n\x1f\x43ustomResourceDefinitionVersion\x12\x84\x01\n\x1a\x61\x64\x64itional_printer_columns\x18\x01 \x03(\x0b\x32`.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceColumnDefinition\x12\x12\n\ndeprecated\x18\x02 \x01(\x08\x12\x1b\n\x13\x64\x65precation_warning\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12j\n\x06schema\x18\x05 \x01(\x0b\x32Z.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceValidation\x12\x0e\n\x06served\x18\x06 \x01(\x08\x12\x0f\n\x07storage\x18\x07 \x01(\x08\x12r\n\x0csubresources\x18\x08 \x01(\x0b\x32\\.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceSubresources\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb0\x01\n\x1e\x43ustomResourceSubresourceScale\x12\x1b\n\x13label_selector_path\x18\x01 \x01(\t\x12\x1a\n\x12spec_replicas_path\x18\x02 \x01(\t\x12\x1c\n\x14status_replicas_path\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Z\n\x1f\x43ustomResourceSubresourceStatus\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb9\x02\n\x1a\x43ustomResourceSubresources\x12o\n\x05scale\x18\x01 \x01(\x0b\x32`.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceSubresourceScale\x12q\n\x06status\x18\x02 \x01(\x0b\x32\x61.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.CustomResourceSubresourceStatus\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc4\x01\n\x18\x43ustomResourceValidation\x12o\n\x14open_a_p_i_v3_schema\x18\x01 \x01(\x0b\x32Q.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaProps\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"r\n\x15\x45xternalDocumentation\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"?\n\x04JSON\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa5\x14\n\x0fJSONSchemaProps\x12q\n\x10\x61\x64\x64itional_items\x18\x01 \x01(\x0b\x32W.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaPropsOrBool\x12v\n\x15\x61\x64\x64itional_properties\x18\x02 \x01(\x0b\x32W.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaPropsOrBool\x12\x61\n\x06\x61ll_of\x18\x03 \x03(\x0b\x32Q.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaProps\x12\x61\n\x06\x61ny_of\x18\x04 \x03(\x0b\x32Q.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaProps\x12W\n\x07\x64\x65\x66\x61ult\x18\x05 \x01(\x0b\x32\x46.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSON\x12w\n\x0b\x64\x65\x66initions\x18\x06 \x03(\x0b\x32\x62.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaProps.DefinitionsEntry\x12y\n\x0c\x64\x65pendencies\x18\x07 \x03(\x0b\x32\x63.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaProps.DependenciesEntry\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12T\n\x04\x65num\x18\t \x03(\x0b\x32\x46.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSON\x12W\n\x07\x65xample\x18\n \x01(\x0b\x32\x46.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSON\x12\x19\n\x11\x65xclusive_maximum\x18\x0b \x01(\x08\x12\x19\n\x11\x65xclusive_minimum\x18\x0c \x01(\x08\x12n\n\rexternal_docs\x18\r \x01(\x0b\x32W.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.ExternalDocumentation\x12\x0e\n\x06\x66ormat\x18\x0e \x01(\t\x12\n\n\x02id\x18\x0f \x01(\t\x12g\n\x05items\x18\x10 \x01(\x0b\x32X.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaPropsOrArray\x12\x11\n\tmax_items\x18\x11 \x01(\x05\x12\x12\n\nmax_length\x18\x12 \x01(\x05\x12\x16\n\x0emax_properties\x18\x13 \x01(\x05\x12\x0f\n\x07maximum\x18\x14 \x01(\x01\x12\x11\n\tmin_items\x18\x15 \x01(\x05\x12\x12\n\nmin_length\x18\x16 \x01(\x05\x12\x16\n\x0emin_properties\x18\x17 \x01(\x05\x12\x0f\n\x07minimum\x18\x18 \x01(\x01\x12\x13\n\x0bmultiple_of\x18\x19 \x01(\x01\x12^\n\x03not\x18\x1a \x01(\x0b\x32Q.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaProps\x12\x10\n\x08nullable\x18\x1b \x01(\x08\x12\x61\n\x06one_of\x18\x1c \x03(\x0b\x32Q.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaProps\x12\x0f\n\x07pattern\x18\x1d \x01(\t\x12\x84\x01\n\x12pattern_properties\x18\x1e \x03(\x0b\x32h.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaProps.PatternPropertiesEntry\x12u\n\nproperties\x18\x1f \x03(\x0b\x32\x61.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.JSONSchemaProps.PropertiesEntry\x12\x10\n\x08required\x18  \x03(\t\x12\r\n\x05title\x18! \x01(\t\x12\x0c\n\x04type\x18\" \x01(\t\x12\x14\n\x0cunique_items\x18# \x01(\x08\x12#\n\x1bxkubernetesembeddedresource\x18$ \x01(\x08\x12\x1e\n\x16xkubernetesintorstring\x18% \x01(\x08\x12\x1e\n\x16xkuberneteslistmapkeys\x18& \x03(\t\x12\x1b\n\x13xkuberneteslisttype\x18\' \x01(\t\x12\x1a\n\x12xkubernetesmaptype\x18( \x01(\t\x12(\n xkubernetespreserveunknownfields\x18) \x01(\x08\x12p\n\x16xkubernetesvalidations\x18* \x03(\x0b\x32P.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.ValidationRule\x12\x37\n\rresource_info\x18+ \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10\x44\x65\x66initionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11\x44\x65pendenciesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x38\n\x16PatternPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x16JSONSchemaPropsOrArray\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"P\n\x15JSONSchemaPropsOrBool\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n\x1cJSONSchemaPropsOrStringArray\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x88\x01\n\x10ServiceReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"h\n\x0eValidationRule\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04rule\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd3\x01\n\x13WebhookClientConfig\x12\x11\n\tca_bundle\x18\x01 \x01(\t\x12\x63\n\x07service\x18\x02 \x01(\x0b\x32R.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.ServiceReference\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xde\x01\n\x11WebhookConversion\x12l\n\rclient_config\x18\x01 \x01(\x0b\x32U.oak9.tython.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1.WebhookClientConfig\x12\"\n\x1a\x63onversion_review_versions\x18\x02 \x03(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.apiextensionsapiserver.pkg.apis.apiextensions.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _JSONSCHEMAPROPS_DEFINITIONSENTRY._options = None
  _JSONSCHEMAPROPS_DEFINITIONSENTRY._serialized_options = b'8\001'
  _JSONSCHEMAPROPS_DEPENDENCIESENTRY._options = None
  _JSONSCHEMAPROPS_DEPENDENCIESENTRY._serialized_options = b'8\001'
  _JSONSCHEMAPROPS_PATTERNPROPERTIESENTRY._options = None
  _JSONSCHEMAPROPS_PATTERNPROPERTIESENTRY._serialized_options = b'8\001'
  _JSONSCHEMAPROPS_PROPERTIESENTRY._options = None
  _JSONSCHEMAPROPS_PROPERTIESENTRY._serialized_options = b'8\001'
  _CUSTOMRESOURCECOLUMNDEFINITION._serialized_start=241
  _CUSTOMRESOURCECOLUMNDEFINITION._serialized_end=432
  _CUSTOMRESOURCECONVERSION._serialized_start=435
  _CUSTOMRESOURCECONVERSION._serialized_end=638
  _CUSTOMRESOURCEDEFINITION._serialized_start=641
  _CUSTOMRESOURCEDEFINITION._serialized_end=1060
  _CUSTOMRESOURCEDEFINITIONCONDITION._serialized_start=1063
  _CUSTOMRESOURCEDEFINITIONCONDITION._serialized_end=1301
  _CUSTOMRESOURCEDEFINITIONLIST._serialized_start=1304
  _CUSTOMRESOURCEDEFINITIONLIST._serialized_end=1608
  _CUSTOMRESOURCEDEFINITIONNAMES._serialized_start=1611
  _CUSTOMRESOURCEDEFINITIONNAMES._serialized_end=1807
  _CUSTOMRESOURCEDEFINITIONSPEC._serialized_start=1810
  _CUSTOMRESOURCEDEFINITIONSPEC._serialized_end=2301
  _CUSTOMRESOURCEDEFINITIONSTATUS._serialized_start=2304
  _CUSTOMRESOURCEDEFINITIONSTATUS._serialized_end=2660
  _CUSTOMRESOURCEDEFINITIONVERSION._serialized_start=2663
  _CUSTOMRESOURCEDEFINITIONVERSION._serialized_end=3208
  _CUSTOMRESOURCESUBRESOURCESCALE._serialized_start=3211
  _CUSTOMRESOURCESUBRESOURCESCALE._serialized_end=3387
  _CUSTOMRESOURCESUBRESOURCESTATUS._serialized_start=3389
  _CUSTOMRESOURCESUBRESOURCESTATUS._serialized_end=3479
  _CUSTOMRESOURCESUBRESOURCES._serialized_start=3482
  _CUSTOMRESOURCESUBRESOURCES._serialized_end=3795
  _CUSTOMRESOURCEVALIDATION._serialized_start=3798
  _CUSTOMRESOURCEVALIDATION._serialized_end=3994
  _EXTERNALDOCUMENTATION._serialized_start=3996
  _EXTERNALDOCUMENTATION._serialized_end=4110
  _JSON._serialized_start=4112
  _JSON._serialized_end=4175
  _JSONSCHEMAPROPS._serialized_start=4178
  _JSONSCHEMAPROPS._serialized_end=6775
  _JSONSCHEMAPROPS_DEFINITIONSENTRY._serialized_start=6563
  _JSONSCHEMAPROPS_DEFINITIONSENTRY._serialized_end=6613
  _JSONSCHEMAPROPS_DEPENDENCIESENTRY._serialized_start=6615
  _JSONSCHEMAPROPS_DEPENDENCIESENTRY._serialized_end=6666
  _JSONSCHEMAPROPS_PATTERNPROPERTIESENTRY._serialized_start=6668
  _JSONSCHEMAPROPS_PATTERNPROPERTIESENTRY._serialized_end=6724
  _JSONSCHEMAPROPS_PROPERTIESENTRY._serialized_start=6726
  _JSONSCHEMAPROPS_PROPERTIESENTRY._serialized_end=6775
  _JSONSCHEMAPROPSORARRAY._serialized_start=6777
  _JSONSCHEMAPROPSORARRAY._serialized_end=6858
  _JSONSCHEMAPROPSORBOOL._serialized_start=6860
  _JSONSCHEMAPROPSORBOOL._serialized_end=6940
  _JSONSCHEMAPROPSORSTRINGARRAY._serialized_start=6942
  _JSONSCHEMAPROPSORSTRINGARRAY._serialized_end=7029
  _SERVICEREFERENCE._serialized_start=7032
  _SERVICEREFERENCE._serialized_end=7168
  _VALIDATIONRULE._serialized_start=7170
  _VALIDATIONRULE._serialized_end=7274
  _WEBHOOKCLIENTCONFIG._serialized_start=7277
  _WEBHOOKCLIENTCONFIG._serialized_end=7488
  _WEBHOOKCONVERSION._serialized_start=7491
  _WEBHOOKCONVERSION._serialized_end=7713
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_cloudiot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gcp/gcp_cloudiot.proto\x12\x18oak9.tython.gcp.cloudiot\x1a\x13shared/shared.proto\"C\n$CloudiotDeviceXCredentialsXPublicKey\x12\x0e\n\x06\x66ormat\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"\x89\x01\n\x1a\x43loudiotDeviceXCredentials\x12\x17\n\x0f\x65xpiration_time\x18\x01 \x01(\t\x12R\n\npublic_key\x18\x02 \x01(\x0b\x32>.oak9.tython.gcp.cloudiot.CloudiotDeviceXCredentialsXPublicKey\"\x97\x01\n\x1c\x43loudiotDeviceXGatewayConfig\x12\x1b\n\x13gateway_auth_method\x18\x01 \x01(\t\x12\x14\n\x0cgateway_type\x18\x02 \x01(\t\x12 \n\x18last_accessed_gateway_id\x18\x03 \x01(\t\x12\"\n\x1alast_accessed_gateway_time\x18\x04 \x01(\t\"I\n\x17\x43loudiotDeviceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa2\x08\n\x0e\x43loudiotDevice\x12\x0f\n\x07\x62locked\x18\x01 \x01(\x08\x12\x44\n\x06\x63onfig\x18\x02 \x03(\x0b\x32\x34.oak9.tython.gcp.cloudiot.CloudiotDevice.ConfigEntry\x12\n\n\x02id\x18\x03 \x01(\t\x12\x1c\n\x14last_config_ack_time\x18\x04 \x01(\t\x12\x1d\n\x15last_config_send_time\x18\x05 \x01(\t\x12X\n\x11last_error_status\x18\x06 \x03(\x0b\x32=.oak9.tython.gcp.cloudiot.CloudiotDevice.LastErrorStatusEntry\x12\x17\n\x0flast_error_time\x18\x07 \x01(\t\x12\x17\n\x0flast_event_time\x18\x08 \x01(\t\x12\x1b\n\x13last_heartbeat_time\x18\t \x01(\t\x12\x17\n\x0flast_state_time\x18\n \x01(\t\x12\x11\n\tlog_level\x18\x0b \x01(\t\x12H\n\x08metadata\x18\x0c \x03(\x0b\x32\x36.oak9.tython.gcp.cloudiot.CloudiotDevice.MetadataEntry\x12\x0c\n\x04name\x18\r \x01(\t\x12\x0e\n\x06num_id\x18\x0e \x01(\t\x12\x10\n\x08registry\x18\x0f \x01(\t\x12\x42\n\x05state\x18\x10 \x03(\x0b\x32\x33.oak9.tython.gcp.cloudiot.CloudiotDevice.StateEntry\x12I\n\x0b\x63redentials\x18\x11 \x03(\x0b\x32\x34.oak9.tython.gcp.cloudiot.CloudiotDeviceXCredentials\x12N\n\x0egateway_config\x18\x12 \x01(\x0b\x32\x36.oak9.tython.gcp.cloudiot.CloudiotDeviceXGatewayConfig\x12\x43\n\x08timeouts\x18\x13 \x01(\x0b\x32\x31.oak9.tython.gcp.cloudiot.CloudiotDeviceXTimeouts\x12\x37\n\rresource_info\x18\x14 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0b\x43onfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x36\n\x14LastErrorStatusEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nStateEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcd\x01\n\x1c\x43loudiotRegistryXCredentials\x12p\n\x16public_key_certificate\x18\x01 \x03(\x0b\x32P.oak9.tython.gcp.cloudiot.CloudiotRegistryXCredentials.PublicKeyCertificateEntry\x1a;\n\x19PublicKeyCertificateEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"a\n)CloudiotRegistryXEventNotificationConfigs\x12\x19\n\x11pubsub_topic_name\x18\x01 \x01(\t\x12\x19\n\x11subfolder_matches\x18\x02 \x01(\t\"K\n\x19\x43loudiotRegistryXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xca\x06\n\x10\x43loudiotRegistry\x12O\n\x0bhttp_config\x18\x01 \x03(\x0b\x32:.oak9.tython.gcp.cloudiot.CloudiotRegistry.HttpConfigEntry\x12\n\n\x02id\x18\x02 \x01(\t\x12\x11\n\tlog_level\x18\x03 \x01(\t\x12O\n\x0bmqtt_config\x18\x04 \x03(\x0b\x32:.oak9.tython.gcp.cloudiot.CloudiotRegistry.MqttConfigEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0e\n\x06region\x18\x07 \x01(\t\x12j\n\x19state_notification_config\x18\x08 \x03(\x0b\x32G.oak9.tython.gcp.cloudiot.CloudiotRegistry.StateNotificationConfigEntry\x12K\n\x0b\x63redentials\x18\t \x03(\x0b\x32\x36.oak9.tython.gcp.cloudiot.CloudiotRegistryXCredentials\x12g\n\x1a\x65vent_notification_configs\x18\n \x03(\x0b\x32\x43.oak9.tython.gcp.cloudiot.CloudiotRegistryXEventNotificationConfigs\x12\x45\n\x08timeouts\x18\x0b \x01(\x0b\x32\x33.oak9.tython.gcp.cloudiot.CloudiotRegistryXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x31\n\x0fHttpConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fMqttConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a>\n\x1cStateNotificationConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"^\n$CloudiotRegistryIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x90\x02\n\x1a\x43loudiotRegistryIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12Q\n\tcondition\x18\x08 \x01(\x0b\x32>.oak9.tython.gcp.cloudiot.CloudiotRegistryIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"]\n#CloudiotRegistryIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8d\x02\n\x19\x43loudiotRegistryIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12P\n\tcondition\x18\x08 \x01(\x0b\x32=.oak9.tython.gcp.cloudiot.CloudiotRegistryIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb2\x01\n\x19\x43loudiotRegistryIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_cloudiot_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLOUDIOTDEVICE_CONFIGENTRY._options = None
  _CLOUDIOTDEVICE_CONFIGENTRY._serialized_options = b'8\001'
  _CLOUDIOTDEVICE_LASTERRORSTATUSENTRY._options = None
  _CLOUDIOTDEVICE_LASTERRORSTATUSENTRY._serialized_options = b'8\001'
  _CLOUDIOTDEVICE_METADATAENTRY._options = None
  _CLOUDIOTDEVICE_METADATAENTRY._serialized_options = b'8\001'
  _CLOUDIOTDEVICE_STATEENTRY._options = None
  _CLOUDIOTDEVICE_STATEENTRY._serialized_options = b'8\001'
  _CLOUDIOTREGISTRYXCREDENTIALS_PUBLICKEYCERTIFICATEENTRY._options = None
  _CLOUDIOTREGISTRYXCREDENTIALS_PUBLICKEYCERTIFICATEENTRY._serialized_options = b'8\001'
  _CLOUDIOTREGISTRY_HTTPCONFIGENTRY._options = None
  _CLOUDIOTREGISTRY_HTTPCONFIGENTRY._serialized_options = b'8\001'
  _CLOUDIOTREGISTRY_MQTTCONFIGENTRY._options = None
  _CLOUDIOTREGISTRY_MQTTCONFIGENTRY._serialized_options = b'8\001'
  _CLOUDIOTREGISTRY_STATENOTIFICATIONCONFIGENTRY._options = None
  _CLOUDIOTREGISTRY_STATENOTIFICATIONCONFIGENTRY._serialized_options = b'8\001'
  _CLOUDIOTDEVICEXCREDENTIALSXPUBLICKEY._serialized_start=73
  _CLOUDIOTDEVICEXCREDENTIALSXPUBLICKEY._serialized_end=140
  _CLOUDIOTDEVICEXCREDENTIALS._serialized_start=143
  _CLOUDIOTDEVICEXCREDENTIALS._serialized_end=280
  _CLOUDIOTDEVICEXGATEWAYCONFIG._serialized_start=283
  _CLOUDIOTDEVICEXGATEWAYCONFIG._serialized_end=434
  _CLOUDIOTDEVICEXTIMEOUTS._serialized_start=436
  _CLOUDIOTDEVICEXTIMEOUTS._serialized_end=509
  _CLOUDIOTDEVICE._serialized_start=512
  _CLOUDIOTDEVICE._serialized_end=1570
  _CLOUDIOTDEVICE_CONFIGENTRY._serialized_start=1374
  _CLOUDIOTDEVICE_CONFIGENTRY._serialized_end=1419
  _CLOUDIOTDEVICE_LASTERRORSTATUSENTRY._serialized_start=1421
  _CLOUDIOTDEVICE_LASTERRORSTATUSENTRY._serialized_end=1475
  _CLOUDIOTDEVICE_METADATAENTRY._serialized_start=1477
  _CLOUDIOTDEVICE_METADATAENTRY._serialized_end=1524
  _CLOUDIOTDEVICE_STATEENTRY._serialized_start=1526
  _CLOUDIOTDEVICE_STATEENTRY._serialized_end=1570
  _CLOUDIOTREGISTRYXCREDENTIALS._serialized_start=1573
  _CLOUDIOTREGISTRYXCREDENTIALS._serialized_end=1778
  _CLOUDIOTREGISTRYXCREDENTIALS_PUBLICKEYCERTIFICATEENTRY._serialized_start=1719
  _CLOUDIOTREGISTRYXCREDENTIALS_PUBLICKEYCERTIFICATEENTRY._serialized_end=1778
  _CLOUDIOTREGISTRYXEVENTNOTIFICATIONCONFIGS._serialized_start=1780
  _CLOUDIOTREGISTRYXEVENTNOTIFICATIONCONFIGS._serialized_end=1877
  _CLOUDIOTREGISTRYXTIMEOUTS._serialized_start=1879
  _CLOUDIOTREGISTRYXTIMEOUTS._serialized_end=1954
  _CLOUDIOTREGISTRY._serialized_start=1957
  _CLOUDIOTREGISTRY._serialized_end=2799
  _CLOUDIOTREGISTRY_HTTPCONFIGENTRY._serialized_start=2635
  _CLOUDIOTREGISTRY_HTTPCONFIGENTRY._serialized_end=2684
  _CLOUDIOTREGISTRY_MQTTCONFIGENTRY._serialized_start=2686
  _CLOUDIOTREGISTRY_MQTTCONFIGENTRY._serialized_end=2735
  _CLOUDIOTREGISTRY_STATENOTIFICATIONCONFIGENTRY._serialized_start=2737
  _CLOUDIOTREGISTRY_STATENOTIFICATIONCONFIGENTRY._serialized_end=2799
  _CLOUDIOTREGISTRYIAMBINDINGXCONDITION._serialized_start=2801
  _CLOUDIOTREGISTRYIAMBINDINGXCONDITION._serialized_end=2895
  _CLOUDIOTREGISTRYIAMBINDING._serialized_start=2898
  _CLOUDIOTREGISTRYIAMBINDING._serialized_end=3170
  _CLOUDIOTREGISTRYIAMMEMBERXCONDITION._serialized_start=3172
  _CLOUDIOTREGISTRYIAMMEMBERXCONDITION._serialized_end=3265
  _CLOUDIOTREGISTRYIAMMEMBER._serialized_start=3268
  _CLOUDIOTREGISTRYIAMMEMBER._serialized_end=3537
  _CLOUDIOTREGISTRYIAMPOLICY._serialized_start=3540
  _CLOUDIOTREGISTRYIAMPOLICY._serialized_end=3718
# @@protoc_insertion_point(module_scope)



import os
from setuptools import setup, find_packages

package_data = {}

for package in find_packages():
    package_data[package] = ["*.pyi"]

version = os.environ.get('PYPIVERSION')
setup_args = dict(
    name="oak9_tython",
    version=version,
    packages=find_packages(),
    package_data=package_data,
    author="Claudio Balbin, Brandon Nicoll",
    author_email="cbalbin@oak9.io, bnicoll@oak9.io",
    description="",
    readme="README.md",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    project_urls={
        "Homepage": "https://github.com/oak9io/tython",
        "Bug Tracker": "https://github.com/oak9io/tython/issues",
    },
    install_requires=[
        'protobuf~=4.21.9',
        'structlog~=21.5.0',
        'GitPython~=3.1.30',
        'requests~=2.28.2',
        'colorama~=0.4.6',
        'braceexpand~=0.1.7',
    ],
    python_requires=">=3.11",
    long_description="oak9 Tython Python framework",
    long_description_content_type="text/markdown",
    # Add these lines to enable debugging:
    options={
        'build_ext': {
            'debug': True
        }
    }
)

if __name__ == '__main__':
    setup(**setup_args)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_RecoveryServices_SiteRecovery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VAULTS_REPLICATION_ALERT_SETTINGS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_FABRICS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_FABRICS_REPLICATION_NETWORKS_REPLICATION_NETWORK_MAPPINGS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_FABRICS_REPLICATION_STORAGE_CLASSIFICATIONS_REPLICATION_STORAGE_CLASSIFICATION_MAPPINGS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_POLICIES_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_PROTECTION_INTENTS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_RECOVERY_PLANS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_VAULT_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def vaults_replication_alert_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationAlertSettings]: ...
    @property
    def vaults_replication_fabrics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationFabrics]: ...
    @property
    def vaults_replication_fabrics_replication_networks_replication_network_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationFabricsReplicationNetworksReplicationNetworkMappings]: ...
    @property
    def vaults_replication_fabrics_replication_storage_classifications_replication_storage_classification_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationFabricsReplicationStorageClassificationsReplicationStorageClassificationMappings]: ...
    @property
    def vaults_replication_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationPolicies]: ...
    @property
    def vaults_replication_protection_intents(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationProtectionIntents]: ...
    @property
    def vaults_replication_recovery_plans(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationRecoveryPlans]: ...
    @property
    def vaults_replication_vault_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationVaultSettings]: ...
    def __init__(
        self,
        *,
        vaults_replication_alert_settings: collections.abc.Iterable[global___VaultsReplicationAlertSettings] | None = ...,
        vaults_replication_fabrics: collections.abc.Iterable[global___VaultsReplicationFabrics] | None = ...,
        vaults_replication_fabrics_replication_networks_replication_network_mappings: collections.abc.Iterable[global___VaultsReplicationFabricsReplicationNetworksReplicationNetworkMappings] | None = ...,
        vaults_replication_fabrics_replication_storage_classifications_replication_storage_classification_mappings: collections.abc.Iterable[global___VaultsReplicationFabricsReplicationStorageClassificationsReplicationStorageClassificationMappings] | None = ...,
        vaults_replication_policies: collections.abc.Iterable[global___VaultsReplicationPolicies] | None = ...,
        vaults_replication_protection_intents: collections.abc.Iterable[global___VaultsReplicationProtectionIntents] | None = ...,
        vaults_replication_recovery_plans: collections.abc.Iterable[global___VaultsReplicationRecoveryPlans] | None = ...,
        vaults_replication_vault_settings: collections.abc.Iterable[global___VaultsReplicationVaultSettings] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["vaults_replication_alert_settings", b"vaults_replication_alert_settings", "vaults_replication_fabrics", b"vaults_replication_fabrics", "vaults_replication_fabrics_replication_networks_replication_network_mappings", b"vaults_replication_fabrics_replication_networks_replication_network_mappings", "vaults_replication_fabrics_replication_storage_classifications_replication_storage_classification_mappings", b"vaults_replication_fabrics_replication_storage_classifications_replication_storage_classification_mappings", "vaults_replication_policies", b"vaults_replication_policies", "vaults_replication_protection_intents", b"vaults_replication_protection_intents", "vaults_replication_recovery_plans", b"vaults_replication_recovery_plans", "vaults_replication_vault_settings", b"vaults_replication_vault_settings"]) -> None: ...

global___Microsoft_RecoveryServices_SiteRecovery = Microsoft_RecoveryServices_SiteRecovery

@typing_extensions.final
class VaultsReplicationVaultSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MIGRATION_SOLUTION_ID_FIELD_NUMBER: builtins.int
    VMWARE_TO_AZURE_PROVIDER_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    migration_solution_id: builtins.str
    vmware_to_azure_provider_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        migration_solution_id: builtins.str = ...,
        vmware_to_azure_provider_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["migration_solution_id", b"migration_solution_id", "name", b"name", "resource_info", b"resource_info", "vmware_to_azure_provider_type", b"vmware_to_azure_provider_type"]) -> None: ...

global___VaultsReplicationVaultSettings = VaultsReplicationVaultSettings

@typing_extensions.final
class VaultsReplicationRecoveryPlans(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FAILOVER_DEPLOYMENT_MODEL_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    PRIMARY_FABRIC_ID_FIELD_NUMBER: builtins.int
    PROVIDER_SPECIFIC_INPUT_FIELD_NUMBER: builtins.int
    RECOVERY_FABRIC_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    failover_deployment_model: builtins.str
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecoveryPlanGroup]: ...
    primary_fabric_id: builtins.str
    @property
    def provider_specific_input(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecoveryPlanProviderSpecificInput]: ...
    recovery_fabric_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        failover_deployment_model: builtins.str = ...,
        groups: collections.abc.Iterable[global___RecoveryPlanGroup] | None = ...,
        primary_fabric_id: builtins.str = ...,
        provider_specific_input: collections.abc.Iterable[global___RecoveryPlanProviderSpecificInput] | None = ...,
        recovery_fabric_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["failover_deployment_model", b"failover_deployment_model", "groups", b"groups", "name", b"name", "primary_fabric_id", b"primary_fabric_id", "provider_specific_input", b"provider_specific_input", "recovery_fabric_id", b"recovery_fabric_id", "resource_info", b"resource_info"]) -> None: ...

global___VaultsReplicationRecoveryPlans = VaultsReplicationRecoveryPlans

@typing_extensions.final
class RecoveryPlanProviderSpecificInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___RecoveryPlanProviderSpecificInput = RecoveryPlanProviderSpecificInput

@typing_extensions.final
class RecoveryPlanGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    END_GROUP_ACTIONS_FIELD_NUMBER: builtins.int
    GROUP_TYPE_FIELD_NUMBER: builtins.int
    REPLICATION_PROTECTED_ITEMS_FIELD_NUMBER: builtins.int
    START_GROUP_ACTIONS_FIELD_NUMBER: builtins.int
    @property
    def end_group_actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecoveryPlanAction]: ...
    group_type: builtins.str
    @property
    def replication_protected_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecoveryPlanProtectedItem]: ...
    @property
    def start_group_actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecoveryPlanAction]: ...
    def __init__(
        self,
        *,
        end_group_actions: collections.abc.Iterable[global___RecoveryPlanAction] | None = ...,
        group_type: builtins.str = ...,
        replication_protected_items: collections.abc.Iterable[global___RecoveryPlanProtectedItem] | None = ...,
        start_group_actions: collections.abc.Iterable[global___RecoveryPlanAction] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_group_actions", b"end_group_actions", "group_type", b"group_type", "replication_protected_items", b"replication_protected_items", "start_group_actions", b"start_group_actions"]) -> None: ...

global___RecoveryPlanGroup = RecoveryPlanGroup

@typing_extensions.final
class RecoveryPlanProtectedItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    VIRTUAL_MACHINE_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    virtual_machine_id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        virtual_machine_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "virtual_machine_id", b"virtual_machine_id"]) -> None: ...

global___RecoveryPlanProtectedItem = RecoveryPlanProtectedItem

@typing_extensions.final
class RecoveryPlanAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_NAME_FIELD_NUMBER: builtins.int
    CUSTOM_DETAILS_FIELD_NUMBER: builtins.int
    FAILOVER_DIRECTIONS_FIELD_NUMBER: builtins.int
    FAILOVER_TYPES_FIELD_NUMBER: builtins.int
    action_name: builtins.str
    @property
    def custom_details(self) -> global___RecoveryPlanActionDetails: ...
    @property
    def failover_directions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def failover_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        action_name: builtins.str = ...,
        custom_details: global___RecoveryPlanActionDetails | None = ...,
        failover_directions: collections.abc.Iterable[builtins.str] | None = ...,
        failover_types: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom_details", b"custom_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_name", b"action_name", "custom_details", b"custom_details", "failover_directions", b"failover_directions", "failover_types", b"failover_types"]) -> None: ...

global___RecoveryPlanAction = RecoveryPlanAction

@typing_extensions.final
class RecoveryPlanActionDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___RecoveryPlanActionDetails = RecoveryPlanActionDetails

@typing_extensions.final
class VaultsReplicationProtectionIntents(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROVIDER_SPECIFIC_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def provider_specific_details(self) -> global___CreateProtectionIntentProviderSpecificDetails: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        provider_specific_details: global___CreateProtectionIntentProviderSpecificDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["provider_specific_details", b"provider_specific_details", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "provider_specific_details", b"provider_specific_details", "resource_info", b"resource_info"]) -> None: ...

global___VaultsReplicationProtectionIntents = VaultsReplicationProtectionIntents

@typing_extensions.final
class CreateProtectionIntentProviderSpecificDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___CreateProtectionIntentProviderSpecificDetails = CreateProtectionIntentProviderSpecificDetails

@typing_extensions.final
class VaultsReplicationPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROVIDER_SPECIFIC_INPUT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def provider_specific_input(self) -> global___PolicyProviderSpecificInput: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        provider_specific_input: global___PolicyProviderSpecificInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["provider_specific_input", b"provider_specific_input", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "provider_specific_input", b"provider_specific_input", "resource_info", b"resource_info"]) -> None: ...

global___VaultsReplicationPolicies = VaultsReplicationPolicies

@typing_extensions.final
class PolicyProviderSpecificInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___PolicyProviderSpecificInput = PolicyProviderSpecificInput

@typing_extensions.final
class VaultsReplicationFabricsReplicationvCenters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FRIENDLY_NAME_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROCESS_SERVER_ID_FIELD_NUMBER: builtins.int
    RUN_AS_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    friendly_name: builtins.str
    ip_address: builtins.str
    port: builtins.str
    process_server_id: builtins.str
    run_as_account_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        friendly_name: builtins.str = ...,
        ip_address: builtins.str = ...,
        port: builtins.str = ...,
        process_server_id: builtins.str = ...,
        run_as_account_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["friendly_name", b"friendly_name", "ip_address", b"ip_address", "name", b"name", "port", b"port", "process_server_id", b"process_server_id", "resource_info", b"resource_info", "run_as_account_id", b"run_as_account_id"]) -> None: ...

global___VaultsReplicationFabricsReplicationvCenters = VaultsReplicationFabricsReplicationvCenters

@typing_extensions.final
class VaultsReplicationFabricsReplicationStorageClassificationsReplicationStorageClassificationMappings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TARGET_STORAGE_CLASSIFICATION_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    target_storage_classification_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        target_storage_classification_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "target_storage_classification_id", b"target_storage_classification_id"]) -> None: ...

global___VaultsReplicationFabricsReplicationStorageClassificationsReplicationStorageClassificationMappings = VaultsReplicationFabricsReplicationStorageClassificationsReplicationStorageClassificationMappings

@typing_extensions.final
class VaultsReplicationFabricsReplicationRecoveryServicesProviders(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTHENTICATION_IDENTITY_INPUT_FIELD_NUMBER: builtins.int
    BIOS_ID_FIELD_NUMBER: builtins.int
    DATA_PLANE_AUTHENTICATION_IDENTITY_INPUT_FIELD_NUMBER: builtins.int
    MACHINE_ID_FIELD_NUMBER: builtins.int
    MACHINE_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_ACCESS_IDENTITY_INPUT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def authentication_identity_input(self) -> global___IdentityProviderInput: ...
    bios_id: builtins.str
    @property
    def data_plane_authentication_identity_input(self) -> global___IdentityProviderInput: ...
    machine_id: builtins.str
    machine_name: builtins.str
    @property
    def resource_access_identity_input(self) -> global___IdentityProviderInput: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        authentication_identity_input: global___IdentityProviderInput | None = ...,
        bios_id: builtins.str = ...,
        data_plane_authentication_identity_input: global___IdentityProviderInput | None = ...,
        machine_id: builtins.str = ...,
        machine_name: builtins.str = ...,
        resource_access_identity_input: global___IdentityProviderInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authentication_identity_input", b"authentication_identity_input", "data_plane_authentication_identity_input", b"data_plane_authentication_identity_input", "resource_access_identity_input", b"resource_access_identity_input", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_identity_input", b"authentication_identity_input", "bios_id", b"bios_id", "data_plane_authentication_identity_input", b"data_plane_authentication_identity_input", "machine_id", b"machine_id", "machine_name", b"machine_name", "name", b"name", "resource_access_identity_input", b"resource_access_identity_input", "resource_info", b"resource_info"]) -> None: ...

global___VaultsReplicationFabricsReplicationRecoveryServicesProviders = VaultsReplicationFabricsReplicationRecoveryServicesProviders

@typing_extensions.final
class IdentityProviderInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AAD_AUTHORITY_FIELD_NUMBER: builtins.int
    APPLICATION_ID_FIELD_NUMBER: builtins.int
    AUDIENCE_FIELD_NUMBER: builtins.int
    OBJECT_ID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    aad_authority: builtins.str
    application_id: builtins.str
    audience: builtins.str
    object_id: builtins.str
    tenant_id: builtins.str
    def __init__(
        self,
        *,
        aad_authority: builtins.str = ...,
        application_id: builtins.str = ...,
        audience: builtins.str = ...,
        object_id: builtins.str = ...,
        tenant_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aad_authority", b"aad_authority", "application_id", b"application_id", "audience", b"audience", "object_id", b"object_id", "tenant_id", b"tenant_id"]) -> None: ...

global___IdentityProviderInput = IdentityProviderInput

@typing_extensions.final
class VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectionContainerMappings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    POLICY_ID_FIELD_NUMBER: builtins.int
    PROVIDER_SPECIFIC_INPUT_FIELD_NUMBER: builtins.int
    TARGET_PROTECTION_CONTAINER_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    policy_id: builtins.str
    @property
    def provider_specific_input(self) -> global___ReplicationProviderSpecificContainerMappingInput: ...
    target_protection_container_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        policy_id: builtins.str = ...,
        provider_specific_input: global___ReplicationProviderSpecificContainerMappingInput | None = ...,
        target_protection_container_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["provider_specific_input", b"provider_specific_input", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "policy_id", b"policy_id", "provider_specific_input", b"provider_specific_input", "resource_info", b"resource_info", "target_protection_container_id", b"target_protection_container_id"]) -> None: ...

global___VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectionContainerMappings = VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectionContainerMappings

@typing_extensions.final
class ReplicationProviderSpecificContainerMappingInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___ReplicationProviderSpecificContainerMappingInput = ReplicationProviderSpecificContainerMappingInput

@typing_extensions.final
class VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectedItems(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    POLICY_ID_FIELD_NUMBER: builtins.int
    PROTECTABLE_ITEM_ID_FIELD_NUMBER: builtins.int
    PROVIDER_SPECIFIC_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    policy_id: builtins.str
    protectable_item_id: builtins.str
    @property
    def provider_specific_details(self) -> global___EnableProtectionProviderSpecificInput: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        policy_id: builtins.str = ...,
        protectable_item_id: builtins.str = ...,
        provider_specific_details: global___EnableProtectionProviderSpecificInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["provider_specific_details", b"provider_specific_details", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "policy_id", b"policy_id", "protectable_item_id", b"protectable_item_id", "provider_specific_details", b"provider_specific_details", "resource_info", b"resource_info"]) -> None: ...

global___VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectedItems = VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectedItems

@typing_extensions.final
class EnableProtectionProviderSpecificInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___EnableProtectionProviderSpecificInput = EnableProtectionProviderSpecificInput

@typing_extensions.final
class VaultsReplicationFabricsReplicationProtectionContainersReplicationMigrationItems(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    POLICY_ID_FIELD_NUMBER: builtins.int
    PROVIDER_SPECIFIC_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    policy_id: builtins.str
    @property
    def provider_specific_details(self) -> global___EnableMigrationProviderSpecificInput: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        policy_id: builtins.str = ...,
        provider_specific_details: global___EnableMigrationProviderSpecificInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["provider_specific_details", b"provider_specific_details", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "policy_id", b"policy_id", "provider_specific_details", b"provider_specific_details", "resource_info", b"resource_info"]) -> None: ...

global___VaultsReplicationFabricsReplicationProtectionContainersReplicationMigrationItems = VaultsReplicationFabricsReplicationProtectionContainersReplicationMigrationItems

@typing_extensions.final
class EnableMigrationProviderSpecificInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___EnableMigrationProviderSpecificInput = EnableMigrationProviderSpecificInput

@typing_extensions.final
class VaultsReplicationFabricsReplicationProtectionContainers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROVIDER_SPECIFIC_INPUT_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_FABRICS_REPLICATION_PROTECTION_CONTAINERS_REPLICATION_MIGRATION_ITEMS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_FABRICS_REPLICATION_PROTECTION_CONTAINERS_REPLICATION_PROTECTED_ITEMS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_FABRICS_REPLICATION_PROTECTION_CONTAINERS_REPLICATION_PROTECTION_CONTAINER_MAPPINGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def provider_specific_input(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplicationProviderSpecificContainerCreationInput]: ...
    @property
    def vaults_replication_fabrics_replication_protection_containers_replication_migration_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationFabricsReplicationProtectionContainersReplicationMigrationItems]: ...
    @property
    def vaults_replication_fabrics_replication_protection_containers_replication_protected_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectedItems]: ...
    @property
    def vaults_replication_fabrics_replication_protection_containers_replication_protection_container_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectionContainerMappings]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        provider_specific_input: collections.abc.Iterable[global___ReplicationProviderSpecificContainerCreationInput] | None = ...,
        vaults_replication_fabrics_replication_protection_containers_replication_migration_items: collections.abc.Iterable[global___VaultsReplicationFabricsReplicationProtectionContainersReplicationMigrationItems] | None = ...,
        vaults_replication_fabrics_replication_protection_containers_replication_protected_items: collections.abc.Iterable[global___VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectedItems] | None = ...,
        vaults_replication_fabrics_replication_protection_containers_replication_protection_container_mappings: collections.abc.Iterable[global___VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectionContainerMappings] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "provider_specific_input", b"provider_specific_input", "resource_info", b"resource_info", "vaults_replication_fabrics_replication_protection_containers_replication_migration_items", b"vaults_replication_fabrics_replication_protection_containers_replication_migration_items", "vaults_replication_fabrics_replication_protection_containers_replication_protected_items", b"vaults_replication_fabrics_replication_protection_containers_replication_protected_items", "vaults_replication_fabrics_replication_protection_containers_replication_protection_container_mappings", b"vaults_replication_fabrics_replication_protection_containers_replication_protection_container_mappings"]) -> None: ...

global___VaultsReplicationFabricsReplicationProtectionContainers = VaultsReplicationFabricsReplicationProtectionContainers

@typing_extensions.final
class ReplicationProviderSpecificContainerCreationInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___ReplicationProviderSpecificContainerCreationInput = ReplicationProviderSpecificContainerCreationInput

@typing_extensions.final
class VaultsReplicationFabricsReplicationNetworksReplicationNetworkMappings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FABRIC_SPECIFIC_DETAILS_FIELD_NUMBER: builtins.int
    RECOVERY_FABRIC_NAME_FIELD_NUMBER: builtins.int
    RECOVERY_NETWORK_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def fabric_specific_details(self) -> global___FabricSpecificCreateNetworkMappingInput: ...
    recovery_fabric_name: builtins.str
    recovery_network_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        fabric_specific_details: global___FabricSpecificCreateNetworkMappingInput | None = ...,
        recovery_fabric_name: builtins.str = ...,
        recovery_network_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fabric_specific_details", b"fabric_specific_details", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fabric_specific_details", b"fabric_specific_details", "name", b"name", "recovery_fabric_name", b"recovery_fabric_name", "recovery_network_id", b"recovery_network_id", "resource_info", b"resource_info"]) -> None: ...

global___VaultsReplicationFabricsReplicationNetworksReplicationNetworkMappings = VaultsReplicationFabricsReplicationNetworksReplicationNetworkMappings

@typing_extensions.final
class FabricSpecificCreateNetworkMappingInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___FabricSpecificCreateNetworkMappingInput = FabricSpecificCreateNetworkMappingInput

@typing_extensions.final
class VaultsReplicationFabrics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CUSTOM_DETAILS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_FABRICS_REPLICATION_PROTECTION_CONTAINERS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_FABRICS_REPLICATION_RECOVERY_SERVICES_PROVIDERS_FIELD_NUMBER: builtins.int
    VAULTS_REPLICATION_FABRICS_REPLICATIONV_CENTERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def custom_details(self) -> global___FabricSpecificCreationInput: ...
    @property
    def vaults_replication_fabrics_replication_protection_containers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationFabricsReplicationProtectionContainers]: ...
    @property
    def vaults_replication_fabrics_replication_recovery_services_providers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationFabricsReplicationRecoveryServicesProviders]: ...
    @property
    def vaults_replication_fabrics_replicationv_centers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsReplicationFabricsReplicationvCenters]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        custom_details: global___FabricSpecificCreationInput | None = ...,
        vaults_replication_fabrics_replication_protection_containers: collections.abc.Iterable[global___VaultsReplicationFabricsReplicationProtectionContainers] | None = ...,
        vaults_replication_fabrics_replication_recovery_services_providers: collections.abc.Iterable[global___VaultsReplicationFabricsReplicationRecoveryServicesProviders] | None = ...,
        vaults_replication_fabrics_replicationv_centers: collections.abc.Iterable[global___VaultsReplicationFabricsReplicationvCenters] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom_details", b"custom_details", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_details", b"custom_details", "name", b"name", "resource_info", b"resource_info", "vaults_replication_fabrics_replication_protection_containers", b"vaults_replication_fabrics_replication_protection_containers", "vaults_replication_fabrics_replication_recovery_services_providers", b"vaults_replication_fabrics_replication_recovery_services_providers", "vaults_replication_fabrics_replicationv_centers", b"vaults_replication_fabrics_replicationv_centers"]) -> None: ...

global___VaultsReplicationFabrics = VaultsReplicationFabrics

@typing_extensions.final
class FabricSpecificCreationInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___FabricSpecificCreationInput = FabricSpecificCreationInput

@typing_extensions.final
class VaultsReplicationAlertSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CUSTOM_EMAIL_ADDRESSES_FIELD_NUMBER: builtins.int
    LOCALE_FIELD_NUMBER: builtins.int
    SEND_TO_OWNERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def custom_email_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    locale: builtins.str
    send_to_owners: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        custom_email_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        locale: builtins.str = ...,
        send_to_owners: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_email_addresses", b"custom_email_addresses", "locale", b"locale", "name", b"name", "resource_info", b"resource_info", "send_to_owners", b"send_to_owners"]) -> None: ...

global___VaultsReplicationAlertSettings = VaultsReplicationAlertSettings
